@@ -537,7 +537,7 @@ MG.Est <- function(dat, Q, model, sequential,att.dist, att.prior,saturated,
        posterior.prob = postP, pf = pf,attributepattern = AlphaPattern,
        testfit = list(Deviance=neg2LL,npar = npar,item.npar = free.item.npar,
                       AIC=2 * npar + neg2LL, BIC=neg2LL + npar * log(N),
-                      CAIC=neg2LL + npar * log(N+1),
+                      CAIC=neg2LL + npar * (log(N)+1),
                       SABIC=neg2LL + npar * log((N+2)/24)),
        technicals = list(logposterior.i = estep$logpost, loglikelihood.i = estep$loglik, free.item.npar = free.item.npar,
                          total.item.npar = total.item.npar, stru.npar = stru.npar, total.npar = npar,
